import json
import requests
import urllib.parse

from PasteMystInfo import PasteMystInfo

BaseURL = 'https://paste.myst.rs/'
APIURL = BaseURL + 'api'

def CreatePasteMyst (Code: str, ExpiresIn: str = 'never', Language: str = None):
    Payload = {
        'code': urllib.parse.quote(Code),
        'expiresIn': ExpiresIn,
    }

    if Language:
        Payload['language'] = Language

    Headers = {
        'content-type': 'application/json'
    }

    Response = requests.post (APIURL + '/paste', data = json.dumps (Payload), headers = Headers, verify = False).json ()

    return MakeObject (Response)

def create_paste_myst (code: str, expires_in: str = 'never', language: str = None):
    return CreatePasteMyst (code, expires_in, language)

def GetPasteMyst (ID: str):
    Response = requests.get (APIURL + '/paste?id=' + ID, data = {}, headers = {}, verify = False).json ()

    return MakeObject (Response)

def get_paste_myst (id: str):
    return GetPasteMyst (id)

def MakeObject (Response: dict):
    return PasteMystInfo (
        Response['id'],
        Response['createdAt'],
        Response['code'],
        Response['expiresIn'],
        Response['language']
    )


import datetime
import urllib.parse

from PasteMyst import BaseURL

class PasteMystInfo (object):
    def __init__ (self, ID: str, CreatedAt: float, Code: str, ExpiresIn: str, Language: str):
        self.ID = ID
        self.CreatedAt = datetime.datetime.fromtimestamp (CreatedAt)
        self.Code = urllib.parse.unquote (Code)
        self.ExpiresIn = ExpiresIn
        self.Language = Language

        self.id = ID
        self.created_at = CreatedAt
        self.code = Code
        self.expires_in = ExpiresIn
        self.language = Language

        self.URL = BaseURL + ID
        self.url = BaseURL + ID


import multiprocessing
from setuptools import setup

with open ('README.md', 'r') as README:
	Description = README.read ()

setup (
	name = 'pastemyst',
	version = '1.2',
	packages = ['pastemyst'],
	author = 'Munchii',
	author_email = 'contact@munchii.me',
	license = 'MIT',
	description = 'Simple API wrapper for paste.myst.rs written in Python',
	long_description = Description,
	long_description_content_type = 'text/markdown',
	url = 'https://github.com/Dmunch04/PasteMyst.py',
	classifiers = [
		'Development Status :: 4 - Beta',
		'Intended Audience :: End Users/Desktop',
            	'Intended Audience :: Developers',
            	'License :: OSI Approved :: MIT License',
            	'Programming Language :: Python :: 3',
            	'Operating System :: OS Independent',
	],
	keywords = 'simple api wrapper python3 python pastemyst pastemyst.rs'
)
